#
# spec file for package uacme
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uacme
Version:        1.7.4
Release:        1.1
Summary:        A minimal ACMEv2 client
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Other
URL:            https://github.com/ndilieto/uacme
Source:         https://github.com/ndilieto/uacme/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE suse-www-path.patch
# find . -type f -exec sed -i 's|/var/www|/srv/www/htdocs|g' {} \;
Patch1:         suse-www-path.patch
Patch2:         %{name}-fix-incorrect-return-types.patch
BuildRequires:  asciidoc
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gnutls) >= 3.3.30
BuildRequires:  pkgconfig(libcurl) >= 7.38.0

%description
uacme is a client for the ACMEv2 protocol described in RFC8555,
written in plain C code with minimal dependencies.
The ACMEv2 protocol allows a Certificate Authority and an
applicant to automate the process of verification and certificate
issuance. The protocol also provides facilities for other
certificate management functions, such as certificate revocation.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
autoreconf -fi
%configure
%make_build

%install
%make_install
mv %{buildroot}/%{_datadir}/doc/uacme/*.html .

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README README.md THANKS
%doc uacme.html ualpn.html
%{_bindir}/uacme
%{_bindir}/ualpn
%{_mandir}/man1/uacme.1%{?ext_man}
%{_mandir}/man1/ualpn.1%{?ext_man}
%dir %{_datadir}/uacme
%{_datadir}/uacme/uacme.sh
%{_datadir}/uacme/ualpn.sh
%{_datadir}/uacme/nsupdate.sh

%changelog
* Tue Jun 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.4:
  * uacme: Validate token from ACME server.
  * minor documentation changes including copyright year
* Sat Dec  3 2022 Adrian Schröter <adrian@suse.de>
- Update to version 1.7.3
  * ualpn.c: fix build with mbedtls 2.x ￼…
  * LibreSSL > 3.5.0 has ASN1_TIME_diff()
  * Enable --must-staple support with LibreSSL > 3.5.0 ￼…
  * Add Unix philosophy link to README.md
  * Compatibility wth LibreSSL
* Mon Aug  8 2022 Yasuhiko Kamata <belphegor@belbel.or.jp>
- Update to version 1.7.2
  * uacme: exponential backoff for status polling instead
    of constant 5s delay (reduces load on server)
  * uacme: new -r option to allow specifying revocation code
  * uacme: fix silent failure in nsupdate.sh
    closes https://github.com/ndilieto/uacme/issues/45
  * uacme: replace 'echo' with 'printf' in uacme.sh
    closes https://github.com/ndilieto/uacme/issues/48
  * uacme: fix -Wsign-compare warning
  * compatibility with mbedTLS v3.2
  * compatibility with LibreSSL (with some limitations)
    see https://github.com/ndilieto/uacme/commit/32546c7c
  * embed ax_check_compile_flag.m4 from autoconf-archive as
    requested in https://github.com/ndilieto/uacme/pull/57
  * minor documentation changes including copyright year
- Removed libev-devel from BuildRequires which causes conflict in
  Tumbleweed.
- Added uacme-fix-incorrect-return-types.patch to be able to build
  in Tumbleweed (original patch is at
  https://github.com/socketry/nio4r/pull/276).
* Tue Apr 19 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.7.1
  * uacme: fix issue when running from inaccessible directory
  * ualpn: use default user group when -u <user> is specified
- Update to version 1.7.0
  * uacme: alternate chain selection by certificate fingerprint
  * print copyright with version
  * ualpn: print copyright with version
  * add notice with version on startup
  * reject duplicate options where appropriate
  * make ualpn.sh always outputs to stderr
  * fix compilation warning
- Update to version 1.6
  * uacme: add support for RFC8555 External Account Binding
  * fix use after free in surrogate strcasestr function
  * make nsupdate.sh accept quoted TXT challenge values
  * minor cosmetic changes to log messages
- Rebased suse-www-path.patch
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.5:
  - uacme: -l option to allow selecting alternate chain
  - ualpn: mbedtls_x509_crt_parse_der_with_ext_cb support
* Sun May 31 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.1
  * fix SIGPIPE of parent process in daemon mode
- Update to version 1.4
  * fix nsupdate.sh
  * uacme: warn that --must-staple is ignored with CSRFILE
  * ualpn: swap -p and -P command line switches
  * ualpn: remove redundant memset
  * ualpn: increase key buffer size as required by OpenSSL 3.x
  * ualpn: fix minor OpenBSD portability issues
  * ualpn: fix typo in warning message
  * ualpn: fix library link order when using built-in libev
  * README.md now included in distribution
- Update to version 1.3
  * allow signing revocation requests with certificate key
  * add support for issuing certificates based on a CSR
  * add mbedTLS implementation of OCSP check
  * add nsupdate.sh dns-01 authentication script
  * improve handling of RFC8738 with OpenSSL/mbedTLS
  * fix memory leak in csr_gen upon some OpenSSL errors
- Update to version 1.2.4
  * improve mbedTLS detection in configure.ac
  * check format string arguments with GCC
  * ualpn: fix incorrect message arguments
* Sun Apr 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.3
  * fix Content-Type header parsing
* Sun Apr 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.2
  * fix ualpn socket type bug on uClibc based systems
  * fix configure.ac MAP_ANON cross-compilation test
* Fri Apr 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.1
  * increase cert buf size to cope with long identifiers
  * fix gcc8 -Wstringop-truncation warning
- Update to version 1.2
  * add uacme OCSP certificate status check
  * add ualpn OpenSSL/mbedTLS implementations
  * add key usage to ualpn challenge certificate
  * ensure top bit of ualpn certificate S/N is 0 with OpenSSL
  * fix ualpn memory leaks and corner case bugs
  * minor cosmetic code and documentation changes
* Fri Mar 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.2
  * fix configure.ac typo affecting LDFLAGS
- Update to version 1.1.1
  * fix typo breaking build without HAVE_SPLICE
  * fix addr_t name collision on s390x
- Update to version 1.1
  * added IP identifier support (RFC8738)
  * added tls-alpn-01 (RFC8737) challenge responder (ualpn)
- Update patch:
  * suse-www-path.patch
- With version 1.1 a new binary named "ualpn" was added.
  "ualpn" can be used as a proxying ACMEv2 tls-alpn-01 responder
- Add libev-devel to BuildRequires (needed by ualpn)
* Thu Mar  5 2020 Adrian Schröter <adrian@suse.de>
- default to /srv/www/htdocs instead of /var/www for web server path
  Add patch:
  * suse-www-path.patch
* Sun Feb  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.22
  * relax account status check (compatibility with buypass.no)
  * allow client challenge retry requests (RFC8555 sec. 7.1.6)
  * pass -L flag to a2x in order to avoid depending on xmllint
  * add wildcard clarification in manpage
- Update to version 1.0.21
  * Fixed uacme.sh: https://github.com/ndilieto/uacme/pull/12
  * Added LFS support (AC_SYS_LARGEFILE)
* Sat Jan  4 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.0.20
